/* $Id: events.h,v 1.3 2004/05/05 15:59:59 thrulliq Exp $ */

#ifndef _EVENTS_H_
#define _EVENTS_H_

/* events handled by monitor */

enum {
	GNOCKY_EVENT_NONE,
	GNOCKY_EVENT_READ_PHONEBOOK,
	GNOCKY_EVENT_WRITE_PHONEBOOK,
	GNOCKY_EVENT_WRITE_PHONEBOOK_ENTRY,
	GNOCKY_EVENT_DELETE_PHONEBOOK_ENTRY,
	GNOCKY_EVENT_READ_BITMAP,
	GNOCKY_EVENT_WRITE_BITMAP,
	GNOCKY_EVENT_READ_SMS_LIST,
	GNOCKY_EVENT_SEND_SMS,
	GNOCKY_EVENT_DELETE_SMS,
	GNOCKY_EVENT_TERMINATE = 0xffff
};

#endif
